@@ -1,4 +1,4 @@
-package Mojo::JSON::Path;
+package Mojo::Response::JSON::Path;
 
 # ABSTRACT: use JSON::Path for searching JSON responses
 
@@ -7,8 +7,6 @@ use Mojo::Message;
 use JSON::Path;
 
 sub import {
-    print 'import: ' . join '; ', @_;
-
     my $class = shift;
 
     install_modifier "Mojo::Message", 'around', 'json',
@@ -18,7 +16,7 @@ sub import {
 
 	    if (@_) {
 		return JSON::Path->new($_[0])->value($orig->($self));
-	    } else { 
+	    } else {
 		return $orig->($self);
 	    }
 	};
